@@ -26,14 +26,21 @@ sub get_inner_html {
     return $_;
 } ## end sub get_inner_html
 
+sub generate_index_url { my ($self, $url) = @_; return $url; }
+
 #解析index内容之前，先做一些简单文本处理
 sub alter_index_before_parse { }
 
+sub generate_chapter_url { my ($self, $url) = @_; return $url; }
+
 #解析chapter内容之前，先做一些简单文本处理
 sub alter_chapter_before_parse { }
 
 #查询结果为多页时，取得除第1页之外的其他结果页面的url
 sub get_query_result_urls { }
 
+
+
+
 no Moo;
 1;
